@@ -22,8 +22,8 @@
 import re
 import os
 import logging
+import shutil
 from subprocess import *
-from shutil import rmtree
 
 
 class CommandFailed(RuntimeError):
@@ -166,6 +166,15 @@ def get_online_processors():
     return threads
 
 
+def get_architecture(rpath):
+    """Return the architecture of the given relative path (Linux tree).
+    If the path does not contain 'arch', return None."""
+    match = re.search(r"arch\/(\w+)\/", rpath)
+    if match:
+        return match.group(1)
+    return None
+
+
 def get_kconfig_items(line):
     """Return a list of all Kconfig items in @line."""
     return re.findall(r"(?:D|\W|\b)+(CONFIG_\w*[A-Z0-9]{1}\w*)", line)
@@ -180,10 +189,10 @@ def generate_models(arch="", cnf=False):
         flags = "-c"
     model_path = os.path.abspath("./models") + "/"
     if os.path.exists(model_path):
-        rmtree(model_path)
+        shutil.rmtree(model_path)
     (out, err) = execute("undertaker-kconfigdump %s %s" % (flags, arch))
     if err != 0:
-        raise RuntimeError("Could not generate model %s" % out)
+        raise RuntimeError("\n".join(out))
     if arch:
         model_path += arch
         if cnf:
