@@ -35,10 +35,10 @@ namespace kconfig {
      * configuration fragement).
      */
     class KconfigAssumptionMap : public std::map<std::string, bool> {
-        PicosatCNF *_model;
+        PicosatCNF *_model = nullptr;
     public:
         //! loads the given models
-        KconfigAssumptionMap(PicosatCNF *model) : _model(model) { };
+        explicit KconfigAssumptionMap(PicosatCNF *model) : _model(model) { };
 
         /**
          * \brief load a partial configuration
@@ -47,5 +47,5 @@ namespace kconfig {
          */
         size_type readAssumptionsFromFile(std::istream &i);
     };
-}
+} // namespace kconfig
 #endif
