@@ -37,8 +37,11 @@ using StringList = std::deque<std::string>;
  * \brief Reads .model files
  */
 class RsfReader : public std::map<std::string, std::string> {
+    RsfReader() = default;
+    std::map<std::string, StringList> meta_information;
+
 public:
-    RsfReader(const std::string &filename, const std::string metaflag = "UNDERTAKER_SET");
+    explicit RsfReader(const std::string &filename, const std::string metaflag = "UNDERTAKER_SET");
     virtual ~RsfReader() = default;
 
     const std::string *getValue(const std::string &key) const;
@@ -48,10 +51,6 @@ public:
     const StringList *getMetaValue(const std::string &key) const;
 
     void print_contents(std::ostream &out);
-
-private:
-    RsfReader() = default;
-    std::map<std::string, StringList> meta_information;
 };
 
 /**
@@ -65,7 +64,7 @@ private:
  */
 class ItemRsfReader : public std::map<std::string, std::string> {
 public:
-    ItemRsfReader(const std::string &filename);
+    explicit ItemRsfReader(const std::string &filename);
     ItemRsfReader() = default;
     const std::string *getValue(const std::string &key) const;
 };
