@@ -46,7 +46,8 @@ class CppFile;
 class SatChecker {
     enum class state {no, yes, module};
 public:
-    SatChecker(const ConfigurationModel * = nullptr, Picosat::SATMode mode = Picosat::SAT_MAX);
+    explicit SatChecker(const ConfigurationModel * = nullptr,
+                        Picosat::SATMode mode = Picosat::SAT_MAX);
 
     virtual ~SatChecker() {};
 
@@ -182,10 +183,8 @@ public:
     }
 
     // Prints the assignments in an human readable way on stdout
-    static void pprintAssignments(std::ostream& out,
-        const std::list<AssignmentMap> solution,
-        const ConfigurationModel *model,
-        const MissingSet &missingSet);
+    static void pprintAssignments(std::ostream &out, const std::list<AssignmentMap> solution,
+                                  const ConfigurationModel *model, const MissingSet &missingSet);
 
     void loadCnfModel(const ConfigurationModel *);
 
@@ -200,7 +199,8 @@ protected:
 
 class BaseExpressionSatChecker : public SatChecker {
 public:
-    BaseExpressionSatChecker(std::string base_expression, const ConfigurationModel * = nullptr);
+    explicit BaseExpressionSatChecker(std::string base_expression,
+                                      const ConfigurationModel * = nullptr);
     virtual ~BaseExpressionSatChecker() {}
     bool operator()(const std::set<std::string> &assumeSymbols);
 };
