@@ -1,8 +1,8 @@
-#if !CONFIG_X86_CPU
+#if !CONFIG_X86
 #endif
 
 /*
- * check-name: Check that choice items are always on
+ * check-name: Check that CONFIG_X86 is always on
  * check-output-start
 I: loaded rsf model for alpha
 I: loaded rsf model for arm
@@ -11,13 +11,14 @@ I: loaded rsf model for blackfin
 I: loaded rsf model for cris
 I: loaded rsf model for frv
 I: loaded rsf model for h8300
+I: loaded rsf model for hexagon
 I: loaded rsf model for ia64
 I: loaded rsf model for m32r
 I: loaded rsf model for m68k
-I: loaded rsf model for m68knommu
 I: loaded rsf model for microblaze
 I: loaded rsf model for mips
 I: loaded rsf model for mn10300
+I: loaded rsf model for openrisc
 I: loaded rsf model for parisc
 I: loaded rsf model for powerpc
 I: loaded rsf model for s390
@@ -25,9 +26,11 @@ I: loaded rsf model for score
 I: loaded rsf model for sh
 I: loaded rsf model for sparc
 I: loaded rsf model for tile
+I: loaded rsf model for um
+I: loaded rsf model for unicore32
 I: loaded rsf model for x86
 I: loaded rsf model for xtensa
-I: found 23 rsf models
+I: found 26 models
 I: Using x86 as primary model
 I: creating always_on.c.B0.kconfig.x86.dead
  * check-output-end
