@@ -18,9 +18,9 @@ int main(void) {
 
 /*
  * check-name: http://sourceforge.net/apps/trac/cppcheck/ticket/1467
- * check-command: undertaker $file
+ * check-command: undertaker -v $file
  * check-output-start
-I: creating cppcheck-define.c.B1.code.globally.undead
-I: creating cppcheck-define.c.B2.code.globally.dead
+I: creating cppcheck-define.c.B1.no_kconfig.globally.undead
+I: creating cppcheck-define.c.B2.no_kconfig.globally.dead
  * check-output-end
  */
