@@ -15,8 +15,9 @@ int main(void) {
 
 /*
  * check-name: multicloud
- * check-command: undertaker $file
+ * check-command: undertaker -v $file
  * check-output-start
-I: creating multicloud-dead.c.B1.code.globally.dead
+I: creating multicloud-dead.c.B0.no_kconfig.globally.undead
+I: creating multicloud-dead.c.B1.no_kconfig.globally.dead
  * check-output-end
  */
