@@ -21,8 +21,8 @@
 
 /*
  * check-name: multicloud
- * check-command: undertaker $file
+ * check-command: undertaker -v $file
  * check-output-start
-I: creating multicloud.c.B4.code.globally.dead
+I: creating multicloud.c.B4.no_kconfig.globally.dead
  * check-output-end
  */
