@@ -2698,13 +2698,14 @@ I: loaded rsf model for blackfin
 I: loaded rsf model for cris
 I: loaded rsf model for frv
 I: loaded rsf model for h8300
+I: loaded rsf model for hexagon
 I: loaded rsf model for ia64
 I: loaded rsf model for m32r
 I: loaded rsf model for m68k
-I: loaded rsf model for m68knommu
 I: loaded rsf model for microblaze
 I: loaded rsf model for mips
 I: loaded rsf model for mn10300
+I: loaded rsf model for openrisc
 I: loaded rsf model for parisc
 I: loaded rsf model for powerpc
 I: loaded rsf model for s390
@@ -2712,23 +2713,37 @@ I: loaded rsf model for score
 I: loaded rsf model for sh
 I: loaded rsf model for sparc
 I: loaded rsf model for tile
+I: loaded rsf model for um
+I: loaded rsf model for unicore32
 I: loaded rsf model for x86
 I: loaded rsf model for xtensa
-I: found 23 rsf models
+I: found 26 models
 I: Using x86 as primary model
+I: creating sb1250-mac.c.B0.code.globally.undead
 I: creating sb1250-mac.c.B1.missing.x86.dead
-I: creating sb1250-mac.c.B2.missing.x86.dead
-I: creating sb1250-mac.c.B4.missing.x86.dead
-I: creating sb1250-mac.c.B5.missing.x86.dead
+I: creating sb1250-mac.c.B10.code.globally.undead
+I: creating sb1250-mac.c.B12.code.globally.undead
+I: creating sb1250-mac.c.B13.code.globally.undead
 I: creating sb1250-mac.c.B14.code.globally.dead
+I: creating sb1250-mac.c.B15.code.globally.undead
 I: creating sb1250-mac.c.B16.code.globally.dead
 I: creating sb1250-mac.c.B17.code.globally.dead
 I: creating sb1250-mac.c.B19.code.globally.undead
+I: creating sb1250-mac.c.B2.missing.x86.dead
 I: creating sb1250-mac.c.B20.code.globally.dead
 I: creating sb1250-mac.c.B21.missing.x86.dead
+I: creating sb1250-mac.c.B22.missing.x86.undead
 I: creating sb1250-mac.c.B23.missing.x86.dead
+I: creating sb1250-mac.c.B26.code.globally.undead
 I: creating sb1250-mac.c.B24.missing.x86.dead
+I: creating sb1250-mac.c.B25.missing.x86.undead
 I: creating sb1250-mac.c.B27.code.globally.dead
+I: creating sb1250-mac.c.B29.code.globally.undead
+I: creating sb1250-mac.c.B3.missing.x86.undead
 I: creating sb1250-mac.c.B30.code.globally.dead
+I: creating sb1250-mac.c.B4.missing.x86.dead
+I: creating sb1250-mac.c.B5.missing.x86.dead
+I: creating sb1250-mac.c.B6.missing.x86.undead
+I: creating sb1250-mac.c.B9.code.globally.undead
  * check-output-end
  */
